# {name}

> Version 0.0.1

[![Build Status](https://travis-ci.org/interrogator/{name}.svg?branch=master)](https://travis-ci.org/interrogator/{name})
[![codecov.io](https://codecov.io/gh/interrogator/{name}/branch/master/graph/badge.svg)](https://codecov.io/gh/interrogator/{name})
[![readthedocs](https://readthedocs.org/projects/{name}/badge/?version=latest)](https://{name}.readthedocs.io/en/latest/)
[![PyPI version](https://badge.fury.io/py/{name}.svg)](https://badge.fury.io/py/{name})
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/python/black)

## Install {name}

```bash
pip install {name}
#or
git clone https://github.com/interrogator/{name} && cd {name} && python.setup.py install
```

## Getting started

```python
from {name} import {name}
```
